/*
  Copyright 2010 Grégory Soutadé

  This file is part of KissCount.

  KissCount is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  KissCount is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with KissCount.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STATSPANEL_H
#define STATSPANEL_H

#include <wx/wx.h>
#include <wx/grid.h>
#include <wx/choice.h>

#include <wx/xy/xyplot.h>
#include <wx/xy/xylinerenderer.h>
#include <wx/xy/xysimpledataset.h>
#include <wx/chart.h>
#include <wx/grid.h>
#include <wx/pie/pieplot.h>
#include <wx/chartpanel.h>
#include <wx/category/categorysimpledataset.h>

#include <controller/KissCount.h>
#include "view.h"
#include <model/model.h>

class StatsPanel: public KissPanel
{
public:
    StatsPanel(KissCount* kiss, wxUI *parent);

    KissPanel* CreatePanel();
    wxBitmapButton* GetButton(int id);
    wxString GetToolTip();
    void OnShow(wxShowEvent& event);

private:
    wxCalendarCtrl* _calendarFrom, *_calendarTo;
    wxChoice* _monthFrom, *_yearFrom, *_monthTo, *_yearTo;
    wxGrid *_statsGrid;
    PiePlot* _pie;
    double *_categoriesValues;
    CategorySimpleDataset* _dataset;
    XYPlot *_plot ;
    wxString* _categories;  
    std::map<wxString, int> _categoriesIndexes;
    wxBoxSizer *_hbox2, *_vbox2;
    wxChartPanel* _chart;
    wxCheckListBox* _account;

    void UpdateStats(int monthFrom, int yearFrom, int monthTo, int yearTo);

    void OnRangeChange(wxCommandEvent& event);
    void OnAccountsChange(wxCommandEvent& event);

    DECLARE_EVENT_TABLE();
};

#endif
